# V1alpha1SuspendTemplate

SuspendTemplate is a template subtype to suspend a workflow at a predetermined point in time
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**duration** | **str** | Duration is the seconds to wait before automatically resuming a template | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


